// Edited 3/17/2015

/*!
	\file
	\brief pin definitions and I/O macros
*/

#ifndef _PROPELLERIZED_H
#define _PROPELLERIZED_H

#include <propeller.h>

#ifndef BSS
	#define BSS __attribute__ ((__section__ (".bss")))
#endif


#ifndef MASK

	/// MASKING- returns \f$2^PIN\f$
	#define MASK(PIN) (1 << PIN)

#endif

/// Read a pin
#define _GET_OUTA(IO) (OUTA & MASK(IO))

/// write to a pin
#define _SET_OUTA(IO, v) do { if (v) { OUTA |= MASK(IO); } else { OUTA &= ~MASK(IO); }; } while (0)

/// set pin as input
#define _SET_DIRA_INPUT(IO) do { DIRA &= ~MASK(IO); } while (0)

/// set pin as output
#define _SET_DIRA_OUTPUT(IO) do { DIRA |=  MASK(IO); } while (0)

// why double up on these macros? see http://gcc.gnu.org/onlinedocs/cpp/Stringification.html

/// Read a pin wrapper
#define GET_OUTA(IO) _GET_OUTA(IO)

/// Write to a pin wrapper
#define SET_OUTA(IO, v) _SET_OUTA(IO, v)

/// set pin as input wrapper
#define SET_DIRA_INPUT(IO) _SET_DIRA_INPUT(IO)

/// set pin as output wrapper
#define SET_DIRA_OUTPUT(IO) _SET_DIRA_OUTPUT(IO)

#endif /* _PROPELLERIZED_H */
